import pytest
from pathlib import Path
import xarray as xr
import pyicon as pyic

@pytest.fixture()
def raw_grid():
    cur_dir = Path(__file__).parent.resolve()
    grid_path = cur_dir / "test_data/icon_grid_0014_R02B04_O.nc"

    if not grid_path.exists():
        import requests
        grid_download_link = "http://icon-downloads.mpimet.mpg.de/grids/public/mpim/0014/icon_grid_0014_R02B04_O.nc"
        try:
            r = requests.get(grid_download_link, allow_redirects=True)
            with open(grid_path, "wb") as grid_file:
                grid_file.write(r.content)
        except:
            raise FileNotFoundError("{grid_path} does not exist and unable to \
                download it")

    ds_grid = xr.open_dataset(grid_path)
    return ds_grid


@pytest.fixture()
def processed_tgrid(raw_grid):
    return pyic.convert_tgrid_data(raw_grid)

@pytest.fixture()
def examp_icon_dataset():
    #cur_dir = Path(__file__).parent.resolve()
    #fpath_data = cur_dir / "test_data/icon_example_data_r2b6.nc"
    path_data = Path(pyic.params['path_example_data'])
    path_data.mkdir(parents=True, exist_ok=True)
    fpath_data = path_data / "icon_example_data_r2b4.nc"

    if not fpath_data.exists():
        import requests
        download_link = "https://swift.dkrz.de/v1/dkrz_07387162e5cd4c81b1376bd7c648bb60/pyicon_example_data/icon_example_data_r2b4.nc"
        try:
            r = requests.get(download_link, allow_redirects=True)
            with open(fpath_data, "wb") as fobj:
                fobj.write(r.content)
        except:
            raise FileNotFoundError("{fpath_data} does not exist and unable to \
                download it")

    ds = xr.open_dataset(fpath_data)
    return ds

@pytest.fixture()
def examp_icon_dataarray(examp_icon_dataset):
    return examp_icon_dataset["to"]

